Learn R Programming

SMLoutliers (version 0.1)

SMLoutliers-package:

Description

We intend to provide host of methods for identifying outliers. This will cut across statistical and machine learning methods.

Arguments

References

M.M. Breunig, H.P. Kriegel, R.T. Ng, and J. Sander. Lof: Identifying density-based local outliers. In Proc. SIGMOD Conf., pages 93-104, 2000.

Examples

Run this code
data(stiff)
summary(stiff)

Run the code above in your browser using DataLab