Four measures of stiffness of 30 boards are available. The first
measure of stiffness is obtained by sending a shock wave down the
board, the second measure is obtained by vibrating the board, and
remaining are obtained from static tests.
Usage
data(stiff)
Arguments
Format
A data frame with 30 observations on the following 4 variables.
x1
first measure of stiffness is obtained by sending a shock
wave down the board
x2
second measure is obtained by vibrating the board
x3
third measure is obtained by a static test
x4
fourth measure is obtained by a static test
References
Johnson, R.A., and Wichern, D.W. (1982-2007). Applied Multivariate
Statistical Analysis, 6e. Pearson Education.
Tattar, et al. (2016). A Course in Statistics with R. J. Wiley.